@@ -55,8 +55,8 @@ class dtv2:
                   '$': 0x30,
                   'm': 0x33,
                   'ù': 0x34,
-                  # '*': 0x35,
-                  # '<': ????,
+                  '*': 0x32,
+                  '<': 0x64,
                   ',': 0x10,
                   ';': 0x36,
                   ':': 0x37,
